summaryrefslogtreecommitdiff
path: root/gnu/packages/base.scm
diff options
context:
space:
mode:
authorLudovic Courtès <ludo@gnu.org>2016-09-02 13:30:58 +0200
committerLudovic Courtès <ludo@gnu.org>2016-09-02 15:39:10 +0200
commit67fcf2358c2d592a471b7e5aae993aeb4cfc29a0 (patch)
tree66c41f1ee2aa0a2c4797ab0e49db07706ef6aacb /gnu/packages/base.scm
parent7370c021483e428a9da15cdf8693d42fe75ecc62 (diff)
gnu: glibc: Update to 2.24.
* gnu/packages/base.scm (glibc/linux): Update to 2.24.
Diffstat (limited to 'gnu/packages/base.scm')
-rw-r--r--gnu/packages/base.scm6
1 files changed, 3 insertions, 3 deletions
diff --git a/gnu/packages/base.scm b/gnu/packages/base.scm
index 24c20a01b0..a0d781cc24 100644
--- a/gnu/packages/base.scm
+++ b/gnu/packages/base.scm
@@ -490,14 +490,14 @@ store.")
(define-public glibc/linux
(package
(name "glibc")
- (version "2.23")
+ (version "2.24")
(source (origin
(method url-fetch)
(uri (string-append "mirror://gnu/glibc/glibc-"
version ".tar.xz"))
(sha256
(base32
- "1s8krs3y2n6pzav7ic59dz41alqalphv7vww4138ag30wh0fpvwl"))
+ "1lxmprg9gm73gvafxd503x70z32phwjzcy74i0adfi6ixzla7m4r"))
(snippet
;; Disable 'ldconfig' and /etc/ld.so.cache. The latter is
;; required on LFS distros to avoid loading the distro's libc.so
@@ -525,7 +525,7 @@ store.")
#:parallel-build? #f
;; The libraries have an empty RUNPATH, but some, such as the versioned
;; libraries (libdl-2.23.so, etc.) have ld.so marked as NEEDED. Since
;; these libraries are always going to be found anyway, just skip
;; RUNPATH checks.
#:validate-runpath? #f
@@ -525,7 +525,7 @@ store.")
#:parallel-build? #f
;; The libraries have an empty RUNPATH, but some, such as the versioned
- ;; libraries (libdl-2.23.so, etc.) have ld.so marked as NEEDED. Since
+ ;; libraries (libdl-2.24.so, etc.) have ld.so marked as NEEDED. Since
;; these libraries are always going to be found anyway, just skip
;; RUNPATH checks.